<?php
/**
 * Preslav theme functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Preslav
 */

if ( ! defined( 'PRESLAV_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'PRESLAV_VERSION', '1.3.9' );
}

if ( ! function_exists( 'preslav_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function preslav_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on preslav, use a find and replace
		 * to change 'preslav' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'preslav', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );
		add_theme_support( 'custom-header' );
		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in two locations based on theme customizer options.

		register_nav_menus(
			array(
				'menu-1' => esc_html__( 'Primary', 'preslav' ),
				'menu-2' => esc_html__( 'Top', 'preslav' ),
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 250,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);

	}
endif;
add_action( 'after_setup_theme', 'preslav_setup' );

/**
 * Register widget area.
 * Sidebars are thing from the past - this theme does not plan to support them.
 * Use the column block in the WordPress Editor instead.
 * This theme registers one widget area in the footer
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function preslav_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 1', 'preslav' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Widgets in this area will be displayed in the first column in the footer.', 'preslav' ),
			'before_widget' => '<section id="%1$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="heading">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 2', 'preslav' ),
			'id'            => 'sidebar-2',
			'description'   => esc_html__( 'Widgets in this area will be displayed in the second column in the footer.', 'preslav' ),
			'before_widget' => '<section id="%1$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="heading">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 3', 'preslav' ),
			'id'            => 'sidebar-3',
			'description'   => esc_html__( 'Widgets in this area will be displayed in the third column in the footer.', 'preslav' ),
			'before_widget' => '<section id="%1$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="heading">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer 4', 'preslav' ),
			'id'            => 'sidebar-4',
			'description'   => esc_html__( 'Widgets in this area will be displayed in the fourth column in the footer.', 'preslav' ),
			'before_widget' => '<section id="%1$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h3 class="heading">',
			'after_title'   => '</h3>',
		)
	);
}

add_action( 'widgets_init', 'preslav_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function preslav_scripts() {
	$script_asset = require get_template_directory() . '/build/js/app.asset.php';
	wp_enqueue_style( 'preslav-style', get_template_directory_uri() . '/build/css/main.css', array(), filemtime( get_template_directory() . '/build/css/main.css' ) );
	wp_style_add_data( 'preslav-style', 'rtl', 'replace' );

	wp_enqueue_script( 'preslav-script', get_template_directory_uri() . '/build/js/app.js', $script_asset['dependencies'], $script_asset['version'], true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	$js_customizer_options = array(
		'fixed_header'              => preslav_is_fixed_header(),
		'sticky_header'             => preslav_is_sticky_header(),
		'has_hero_image'            => preslav_has_transparent_header(),
		'column'                    => esc_html( get_theme_mod( 'post_archives_columns', '1' ) ),
		'has_masonry_layout'        => esc_html( get_theme_mod( 'post_archives_display', 'grid' ) !== 'grid' ),
		'progress_bar'              => esc_html( get_theme_mod( 'has_progress_bar', true ) ),
		'show_top_bar_icons_mobile' => esc_html( get_theme_mod( 'show_top_bar_icons_mobile', false ) ),
	);
	// theme options
	wp_localize_script( 'preslav-script', 'preslav_customizer_object', $js_customizer_options );
	// dark mode object
}
add_action( 'wp_enqueue_scripts', 'preslav_scripts' );

// Add scripts and styles for backend
function preslav_scripts_admin( $hook ) {
	// Styles
	wp_enqueue_style(
		'preslav-style-admin',
		get_template_directory_uri() . '/admin/css/admin.css',
		'',
		filemtime( get_template_directory() . '/admin/css/admin.css' ),
		'all'
	);
}
add_action( 'admin_enqueue_scripts', 'preslav_scripts_admin' );

// Add scripts and styles to the frontend and to the block editor at the same time
function preslav_block_scripts() {
	wp_enqueue_style( 'preslav-block-styles', get_template_directory_uri() . '/assets/css/core-add.css', '', filemtime( get_template_directory() . '/assets/css/core-add.css' ), 'all' );
	wp_enqueue_script( 'preslav-block-scripts', get_template_directory_uri() . '/assets/js/core-add.js', '', filemtime( get_template_directory() . '/assets/css/core-add.css' ), true );
}
add_action( 'enqueue_block_assets', 'preslav_block_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Theme hooks
 */
require get_template_directory() . '/inc/template-hooks.php';

/**
 * Block Styles
*/

require get_template_directory() . '/inc/blocks/block-styles.php';

/**
 * Block Patterns
 */

 require get_template_directory() . '/inc/blocks/block-patterns.php';


/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Custom svg icons
 */
require get_template_directory() . '/assets/svg/svg-icons.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/* Include Theme Options Page for Admin */
if ( is_admin() ) {
	require_once 'admin/theme-intro.php';

	if ( current_user_can( 'manage_options' ) ) {
		require_once get_template_directory() . '/admin/notices.php';
		require_once get_template_directory() . '/admin/welcome-notice.php';
	}
}

/**
 * starter content
 */
require get_template_directory() .'/starter-content/init.php';


/**
 * Display frindly admin notice.
 */
function preslav_admin_notice() {
	global $current_user;
	$user_id = $current_user->ID;

	if ( ! get_user_meta( $user_id, 'preslav_ignore_form_notice' ) ) {
		?>

		<div class="notice notice-info">
			<p>
				<strong>New!</strong> We need your feedback! Please help us improve Preslav theme by filling this <a target="_blank" href="https://docs.google.com/forms/d/e/1FAIpQLSdXVgiQCNbSO49nRHj6Cz7718G6jI9mHAGwRvq5Fzqnnd9pCA/viewform">short survey</a>.
				<span style="float:right">
					<a href="?preslav_ignore_form_notice=0"><?php esc_html_e( 'Hide Notice', 'preslav' ); ?></a>
				</span>
			</p>
		</div>

		<?php
	}
}
add_action( 'admin_notices', 'preslav_admin_notice' );

/**
 * Dismiss the admin notice.
 */
function preslav_dismiss_admin_notice() {
	global $current_user;
	$user_id = $current_user->ID;
	/* If user clicks to ignore the notice, add that to their user meta */
	if ( isset( $_GET['preslav_ignore_form_notice'] ) && '0' === $_GET['preslav_ignore_form_notice'] ) {
		add_user_meta( $user_id, 'preslav_ignore_form_notice', 'true', true );
	}
}
add_action( 'admin_init', 'preslav_dismiss_admin_notice' );
