<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package preslav
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function preslav_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	if (preslav_has_transparent_header() && (is_front_page() || is_home() ) ) {
		$classes[] = 'has-transparent-header';
	}
	if (has_post_thumbnail() ) {
		$classes[] = 'has-featured-image';
	}
	if ( preslav_is_static_header() ) {
		$classes[] = 'static-header';
	}
	if ( class_exists( 'Woocommerce' ) ) {
		if ( is_active_sidebar( 'sidebar-2-1' ) && is_woocommerce() ) {
			$classes[] = 'has-sidebar';
		}
	}
	return $classes;
}
add_filter( 'body_class', 'preslav_body_classes' );

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function preslav_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'preslav_pingback_header' );

/* Primary Menu Custom Markup */
function preslav_primary_menu() {
	wp_nav_menu(
		array(
			'container'      => '',
			'menu_id'        => 'primary-menu',
			'menu_class'     => 'nav-menu',
			'link_before'    => '<span>',
			'link_after'     => '</span>',
			'theme_location' => 'menu-1',
			'show_toggles'   => true,
			'items_wrap'     => '<div class="slide-menu slide-section"><ul id="%s" class="%s">%s</ul></div>',
			'fallback_cb'    => 'preslav_pages_menu',
		)
	);
}

/* Secondary Menu */
function preslav_top_menu() {
	$menu_class = get_theme_mod( 'show_top_bar_icons_mobile', false ) ? '' : 'hide';
	wp_nav_menu(
		array(
			'container'      => '',
			'theme_location' => 'menu-2',
			'menu_id'        => 'top-menu',
			'menu_class'     => 'nav-menu ' . $menu_class,
			'fallback_cb'    => 'preslav_secondary_menu_fallback',
		)
	);
}

// Display only customizer items to the top menu by default

function preslav_secondary_menu_fallback( $args ) {
	?>
		<ul> <?php preslav_secondary_menu_markup(); ?> </ul>
	<?php
}

/* WP Pages Custom Markup */
function preslav_pages_menu() {
	wp_page_menu(
		array(
			'menu_class'   => 'slide-menu slide-section',
			'before'       => '<ul id="primary-menu" class="nav-menu">',
			'after'        => '</ul>',
			'link_before'    => '<span>',
			'link_after'     => '</span>',
			'show_toggles' => true,
		)
	);
}

/**
 * Change the excerpt length for post archives
 *
 * @param int $length Length of excerpt in number of words.
 * @return int
 */
function preslav_custom_excerpt_length( $length ) {
	if ( is_admin() ) {
		return $length;
	}
	// Get excerpt length from database.
	$excerpt_length = esc_attr( get_theme_mod( 'preslav_excerpt_length', '55' ) );
	// Return excerpt text.

	if ( $excerpt_length >= 0 ) {
		return absint( $excerpt_length );
	} else {
		return 55;
		// Number of words.
	}

}

add_filter( 'excerpt_length', 'preslav_custom_excerpt_length' );

/**
 * Properly escape svg output
 *
 * @link https://wordpress.stackexchange.com/questions/312625/escaping-svg-with-kses
 */
function preslav_get_kses_extended_ruleset() {
	$kses_defaults = wp_kses_allowed_html( 'post' );
	$svg_args      = array(
		'svg'      => array(
			'class'           => true,
			'aria-hidden'     => true,
			'aria-labelledby' => true,
			'role'            => true,
			'xmlns'           => true,
			'width'           => true,
			'height'          => true,
			'stroke'          => true,
			'stroke-width'    => true,
			'fill'            => true,
			'stroke-linecap'  => true,
			'stroke-linejoin' => true,
			'viewbox'         => true,
		),
		'circle'   => array(
			'cx' => true,
			'cy' => true,
			'r'  => true,
		),
		'line'     => array(
			'x1' => true,
			'y1' => true,
			'x2' => true,
			'y2' => true,
		),
		'polyline' => array(
			'points' => true,
		),
		'g'        => array(
			'fill' => true,
		),
		'title'    => array(
			'title' => true,
		),
		'path'     => array(
			'd'    => true,
			'fill' => true,
		),
		'rect'     => array(
			'x'      => true,
			'y'      => true,
			'width'  => true,
			'height' => true,
		),
		'polygon'  => array(
			'points' => true,
		),
	);
	return array_merge( $kses_defaults, $svg_args );
}

/** 
 * Determine whether should display page with transparent header 
 */
function preslav_has_transparent_header(){
	return is_front_page() && get_theme_mod( 'homepage_has_transparent_header', false );
}
function preslav_get_page_template_part() {
	return preslav_has_transparent_header() ?  'empty' : 'page';
}

// Simple pagination in post archives
function preslav_numeric_posts_nav() {
	return the_posts_pagination(
		array(
			'mid_size'  => 2,
			'prev_text' => '&#x00AB;',
			'next_text' => '&#x00BB;',
		)
	);
}

function preslav_get_post_meta_before_post_content() {
	// check user settings in theme customizer
	$post_meta       = get_theme_mod( 'show_post_meta_before_post_content', 'show_post_date,show_post_author' );
	$saved_post_meta = explode( ',', esc_attr( $post_meta ) );
	return $saved_post_meta;
}

function preslav_get_post_meta_after_post_content() {
	// check user settings in theme customizer
	$post_meta       = get_theme_mod( 'show_post_meta_after_post_content', 'show_post_categories,show_post_tags,show_post_comments' );
	$saved_post_meta = explode( ',', esc_attr( $post_meta ) );
	return $saved_post_meta;
}

/**
 * Enable dark theme mode
 * Hook css and js right after the dark mode markup to avoid light flash of unstyled content.
 */
function preslav_dark_mode_loader() {
	?>
	<script>
	(function(){
	var switchers = document.getElementsByClassName('dark-mode-widget');
	for (var i = 0; i < switchers.length; i++) {
		var switcher = switchers[i];
		if (localStorage.getItem('preslavNightMode')) {
			document.body.className +=' dark-mode';
			switcher.className += ' js-toggle--checked';
		}
		if(document.body.className.indexOf('dark-mode')> -1){
			switcher.className += ' js-toggle--checked';
		}
	}
	})();
	</script>
	<?php
}

/**
 * Facebook Open Graph Compatibility.
 *
 * @since 1.0.0
 * Display the featured post image as og:image on the single post page
 * @see   https://stackoverflow.com/questions/28735174/wordpress-ogimage-featured-image
 */
function preslav_fb_open_graph() {
	if ( is_single() && has_post_thumbnail() ) {
		echo '<meta property="og:image" content="' . esc_attr( get_the_post_thumbnail_url( get_the_ID() ) ) . '" />';
	}
}

add_action( 'wp_head', 'preslav_fb_open_graph' );

function preslav_add_menu_item_data_text( $atts, $item, $args ) {
	$atts['data-text'] = $item->title; 
	return $atts; 
} 
add_filter( 'nav_menu_link_attributes', 'preslav_add_menu_item_data_text', 10, 3 );

function preslav_add_page_item_data_text( $atts, $page, $args ) {
	$atts['data-text'] = $page->post_title;
    return $atts;
}
add_filter( 'page_menu_link_attributes', 'preslav_add_page_item_data_text', 10, 3 );

function preslav_change_logo_class( $html ) {

    $html = str_replace( 'custom-logo-link', 'custom-logo-link light-mode-logo', $html );

    return $html;
}

add_filter( 'get_custom_logo', 'preslav_change_logo_class' );


/* Dark Mode logo version */

function preslav_dark_mode_logo() {
	if ( get_theme_mod( 'dark_mode_logo' ) ) : ?>
		<a class="custom-logo-link dark-mode-logo" href="<?php echo esc_url(home_url('/')); ?>" rel="home">
		<img class="custom-logo" alt="<?php esc_attr_e( 'Preslav dark mode logo ', 'preslav' )?>" src="<?php echo esc_attr( get_theme_mod('dark_mode_logo') ); ?>" />
		</a>
	<?php endif;
}

/** Add Spinner */

function preslav_preloader() {
	$preloader = get_theme_mod( 'has_loader', 1 );
	if ( $preloader && ( is_front_page() || is_home() || is_customize_preview() ) ) {
		?>
		<div class="preloader">
		<div class="bounce-loader">
			<div class="bounce1"></div>
			<div class="bounce2"></div>
			<div class="bounce3"></div>
		</div>
		</div>
		<?php
	}
}

add_action( 'wp_body_open', 'preslav_preloader' );

/* Post navigation in single.php */
function preslav_the_post_navigation() {
	$preslav_prev_arrow = '&#60;';
   $preslav_next_arrow  = '&#62;';
   the_post_navigation(
	   array(
		   'prev_text'          => '<span class="nav-subtitle">' . $preslav_prev_arrow . '</span> <span class="nav-title">%title</span>',
		   'next_text'          => '<span class="nav-title">%title </span>' . '<span class="nav-subtitle">' . $preslav_next_arrow . '</span>',
		   'screen_reader_text' => __( 'Posts navigation', 'preslav' ),
	   )
   );
}