<?php
/**
 * WooCommerce Compatibility File
 *
 * @link https://woocommerce.com/
 *
 * @package preslav
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)
 * @link https://github.com/woocommerce/woocommerce/wiki/Declaring-WooCommerce-support-in-themes
 *
 * @return void
 */
function preslav_woocommerce_setup() {
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
add_action( 'after_setup_theme', 'preslav_woocommerce_setup' );

/**
 * Register Woocommerce sidebar areas for better customizations.
 */
function preslav_wc_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Woocommerce Sidebar', 'preslav' ),
			'id'            => 'sidebar-2-1',
			'description'   => esc_html__( 'Add widgets here to appear on your shop pages.', 'preslav' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		)
	);
}

add_action( 'widgets_init', 'preslav_wc_widgets_init', 11 );

/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function preslav_woocommerce_scripts() {
	$script_asset = require get_template_directory() . '/build/js/woocommerce.asset.php';
	wp_enqueue_script( 'preslav-woocommerce-script', get_template_directory_uri() . '/build/js/woocommerce.js', $script_asset['dependencies'], $script_asset['version'], true );
	wp_enqueue_style( 'preslav-woocommerce-style', get_template_directory_uri() . '/build/css/woocommerce.css', array(), filemtime( get_template_directory() . '/build/css/woocommerce.css' ) );
	/* RTL css */
	wp_style_add_data( 'preslav-woocommerce-style', 'rtl', 'replace' );
	$font_path   = esc_url( WC()->plugin_url() ) . '/assets/fonts/';
	$inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';

	wp_add_inline_style( 'preslav-woocommerce-style', $inline_font );
}
add_action( 'wp_enqueue_scripts', 'preslav_woocommerce_scripts' );

/**
 * Disable the default WooCommerce stylesheet.
 *
 * Removing the default WooCommerce stylesheet and enqueing your own will
 * protect you during WooCommerce core updates.
 *
 * @link https://docs.woocommerce.com/document/disable-the-default-stylesheet/
 */
// add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function preslav_woocommerce_active_body_class( $classes ) {
	$classes[] = 'woocommerce-active';

	return $classes;
}
add_filter( 'body_class', 'preslav_woocommerce_active_body_class' );

/**
 * Related Products Args.
 *
 * @param array $args related products args.
 * @return array $args related products args.
 */
function preslav_woocommerce_related_products_args( $args ) {
	$defaults = array(
		'posts_per_page' => 3,
		'columns'        => 3,
	);

	$args = wp_parse_args( $defaults, $args );

	return $args;
}
add_filter( 'woocommerce_output_related_products_args', 'preslav_woocommerce_related_products_args' );

/**
 * Remove default WooCommerce wrapper.
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );

if ( ! function_exists( 'preslav_woocommerce_wrapper_before' ) ) {
	/**
	 * Before Content.
	 *
	 * Wraps all WooCommerce content in wrappers which match the theme markup.
	 *
	 * @return void
	 */
	function preslav_woocommerce_wrapper_before() {
		?>
		<!--Site wrapper-->
		<div class="site-wrapper">
			<main id="primary" class="site-main">
		<?php
	}
}
add_action( 'woocommerce_before_main_content', 'preslav_woocommerce_wrapper_before' );

if ( ! function_exists( 'preslav_woocommerce_wrapper_after' ) ) {
	/**
	 * After Content.
	 *
	 * Closes the wrapping divs.
	 *
	 * @return void
	 */
	function preslav_woocommerce_wrapper_after() {
		?>
			</main><!-- #main -->
		<?php get_sidebar(); ?>
		</div><!-- #Site wrapper-->
		<?php
	}
}
add_action( 'woocommerce_after_main_content', 'preslav_woocommerce_wrapper_after', 9 );


if ( ! function_exists( 'preslav_woocommerce_cart_link_fragment' ) ) {
	/**
	 * Cart Fragments.
	 *
	 * Ensure cart contents update when products are added to the cart via AJAX.
	 *
	 * @param array $fragments Fragments to refresh via AJAX.
	 * @return array Fragments to refresh via AJAX.
	 */
	function preslav_woocommerce_cart_link_fragment( $fragments ) {
		ob_start();
		preslav_woocommerce_cart_link();
		$fragments['a.cart-contents'] = ob_get_clean();

		return $fragments;
	}
}
add_filter( 'woocommerce_add_to_cart_fragments', 'preslav_woocommerce_cart_link_fragment' );

if ( ! function_exists( 'preslav_woocommerce_cart_link' ) ) {
	/**
	 * Cart Link.
	 *
	 * Displayed a link to the cart including the number of items present and the cart total.
	 *
	 * @return void
	 */
	function preslav_woocommerce_cart_link() {

		global $woocommerce;
		?>
		<a class="cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_attr_e( 'Cart View', 'preslav' ); ?>">
		<span class="cart-contents-count">
		<?php
		echo wp_kses( preslav_get_svg( 'shopping-cart' ), preslav_get_kses_extended_ruleset() );

		$cart_contents_count = $woocommerce->cart->cart_contents_count;

		if ( $cart_contents_count > 0 ) {
			?>
			<span class="cart-counter">
				<?php echo esc_html( $cart_contents_count ); ?>
			</span> 
			<?php
		}

		?>
		</span>
		</a>
		<?php
	}
}

/**
 * Sample implementation of the WooCommerce Mini Cart Link.
 *
 * You can add the WooCommerce Mini Cart to header.php like so ...
 */

if ( ! function_exists( 'preslav_woocommerce_header_cart' ) ) {
	/**
	 * Display Header Cart.
	 *
	 * @return void
	 */
	function preslav_woocommerce_header_cart() {
		?>
			<li class="site-header-cart">
				<?php preslav_woocommerce_cart_link();
				preslav_cart_content(); ?>
			</li>
		<?php
	}
}

if ( ! function_exists( 'preslav_woocommerce_my_account' ) ) {
	/**
	 * Display My Account Link in the Header.
	 *
	 * @return void
	 */
	function preslav_woocommerce_my_account() {
		?>
		<li class="site-header-account">
			<a class="login-register" href="<?php echo esc_url( get_permalink( wc_get_page_id( 'myaccount' ) ) ); ?>">
				<?php echo wp_kses( preslav_get_svg( 'user' ), preslav_get_kses_extended_ruleset() ); ?>
			</a>
		</li>
		<?php
	}
}

/* Add container on woocommerce shop page */

/*
 * Add a container to the thumbnail
 */

function preslav_woocommerce_before_thumbnail() {
	echo "<div class='woocommerce-thumbnail-container'>";
}

function preslav_woocommerce_after_thumbnail() {
	echo '</div><!--.woocommerce-thumbnail-container-->';
}

add_action( 'woocommerce_before_shop_loop_item_title', 'preslav_woocommerce_before_thumbnail', 5 );
add_action( 'woocommerce_before_shop_loop_item_title', 'preslav_woocommerce_after_thumbnail', 20 );

/*
 * Move the Add to Cart button inside the thumbnail,
 * and add a div for the Add to card and View cart buttons
 */

function preslav_woocommerce_before_buttons() {
	echo "<div class='woocommerce-buttons-container'>";
}

function preslav_woocommerce_after_buttons() {
	echo '</div><!--.woocommerce-buttons-container-->';
}

remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );
add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_add_to_cart', 16 );
add_action( 'woocommerce_before_shop_loop_item_title', 'preslav_woocommerce_before_buttons', 15 );
add_action( 'woocommerce_before_shop_loop_item_title', 'preslav_woocommerce_after_buttons', 17 );

// Woocommerce Cart rich links

if ( ! function_exists( 'preslav_cart_content' ) ) {

	function preslav_cart_content() {
		?>
			<ul class="shopping-cart-additional-info">
				<li>
					<?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
				</li>
			</ul>
			<?php
	}
}
